Module reader

Module reader 

Structs

Reader
ARGF-style multi-source streaming reader.
TeeFilter
Wraps a chunk-producing closure and also writes each chunk to stdout. Used in btee mode.

Enums

Format
A single input source (stdin, a file path, or a command to run).

Functions

sniff
Peek at the first chunk to determine whether it looks like HTML. Returns Format::Html if the first non-whitespace byte is <.