serve

Function serve 

pub async fn serve<F>(cfg: ServerConfig, on_bind: F) -> ServerHandle
where F: FnOnce(SocketAddr),
Bind the server, return a handle for feeding chunks and the bound address. Calls on_bind with the bound address synchronously before returning so the caller can open a browser URL pointing at the right port.